@@ -8,15 +8,10 @@ AGENTMAKE_USER_DIR = os.getenv("AGENTMAKE_USER_DIR") if os.getenv("AGENTMAKE_USE
 def load_configurations(env_file=""):
     if not env_file:
         backup_env = os.path.join(AGENTMAKE_USER_DIR, "agentmake.env")
-        if os.path.isfile(backup_env):
-            env_file = backup_env
-        else:
-            default_env_file = os.path.join(PACKAGE_PATH, ".env")
-            if not os.path.isfile(default_env_file):
-                shutil.copy(os.path.join(PACKAGE_PATH, "agentmake.env"), default_env_file)
-            env_file = default_env_file
-    if os.path.isfile(env_file):
-        load_dotenv(env_file)
+        if not os.path.isfile(backup_env):
+            shutil.copy(os.path.join(PACKAGE_PATH, "agentmake.env"), backup_env)
+    if os.path.isfile(backup_env):
+        load_dotenv(backup_env)
 load_configurations()
 
 from .backends.anthropic import AnthropicAI
@@ -33,6 +28,7 @@ from .backends.groq import GroqAI
 from .backends.llamacpp import LlamacppAI
 from .backends.mistral import MistralAI
 from .backends.ollama import OllamaAI
+from .backends.ollamacloud import OllamacloudAI
 from .backends.openai import OpenaiAI
 from .backends.xai import XaiAI
 
@@ -52,7 +48,7 @@ AGENTMAKE_ASSISTANT_NAME = os.getenv("AGENTMAKE_ASSISTANT_NAME") if os.getenv("A
 AGENTMAKE_USERNAME = os.getenv("AGENTMAKE_USERNAME") if os.getenv("AGENTMAKE_USERNAME") else getpass.getuser().capitalize()
 USER_OS = "macOS" if platform.system() == "Darwin" else platform.system()
 DEVELOPER_MODE = True if os.getenv("DEVELOPER_MODE") and os.getenv("DEVELOPER_MODE").upper() == "TRUE" else False
-SUPPORTED_AI_BACKENDS = ["anthropic", "azure", "azure_any", "cohere", "custom", "deepseek", "genai", "github", "github_any", "googleai", "groq", "llamacpp", "mistral", "ollama", "openai", "vertexai", "xai"]
+SUPPORTED_AI_BACKENDS = ["anthropic", "azure", "azure_any", "cohere", "custom", "deepseek", "genai", "github", "github_any", "googleai", "groq", "llamacpp", "mistral", "ollama", "ollamacloud", "openai", "vertexai", "xai"]
 DEFAULT_AI_BACKEND = os.getenv("DEFAULT_AI_BACKEND") if os.getenv("DEFAULT_AI_BACKEND") else "ollama"
 RAW_SYSTEM_MESSAGE = f"You are my personal AI assistant. I am your user, {AGENTMAKE_USERNAME}. I will give you both text-based and non-text-based tasks, and the necessary tools to resolve my requests. Therefore, do not tell me that you are only a text-based language model. Try your best to resolve my requests. Do not address my name more than once in a single conversation unless I request it."
 DEFAULT_SYSTEM_MESSAGE = os.getenv("DEFAULT_SYSTEM_MESSAGE") if os.getenv("DEFAULT_SYSTEM_MESSAGE") else RAW_SYSTEM_MESSAGE
@@ -155,7 +151,7 @@ def agentmake(
         backend:
             type: Optional[str]="ollama"
             AI backend
-            supported backends: "anthropic", "azure", "azure_any", "cohere", "custom", "deepseek", "genai", "github", "github_any", "googleai", "groq", "llamacpp", "mistral", "ollama", "openai", "vertexai", "xai"
+            supported backends: "anthropic", "azure", "azure_any", "cohere", "custom", "deepseek", "genai", "github", "github_any", "googleai", "groq", "llamacpp", "mistral", "ollama", "ollamacloud", "openai", "vertexai", "xai"
 
         model:
             type: Optional[str]=None
@@ -723,7 +719,7 @@ def agentmake(
                             word_wrap=word_wrap,
                             **kwargs,
                         ) # returned response can be either 1) an empty string: no chat extension 2) a non-empty string: chat extension 3) none: errors encountered in executing the function
-                    function_text_output = terminal_output.getvalue().replace("```output\n```\n", "Done!") # capture the function text output for function calling without chat extension
+                    function_text_output = terminal_output.getvalue().replace("```output\n```\n", "[NO_CONTENT]") # capture the function text output for function calling without chat extension
                     # Restore the original stdout
                     sys.stdout = old_stdout
                 except Exception as e:
@@ -770,7 +766,7 @@ def agentmake(
                         **kwargs
                     )
                 else: # empty str; function executed successfully without chat extension
-                    output = function_text_output if function_text_output else "Done!"
+                    output = function_text_output if function_text_output else "[NO_CONTENT]"
             else: # structured output
                 output = json.dumps(dictionary_output)
             if print_on_terminal:
@@ -958,6 +954,22 @@ def agentmake(
                     api_endpoint=api_endpoint,
                     **kwargs
                 )
+            elif backend == "ollamacloud":
+                completion = OllamacloudAI.getChatCompletion(             
+                    messages_copy,
+                    model=model,
+                    model_keep_alive=model_keep_alive,
+                    temperature=temperature,
+                    max_tokens=max_tokens,
+                    context_window=context_window,
+                    batch_size=batch_size,
+                    prefill=prefill_content,
+                    stop=stop,
+                    stream=stream,
+                    api_key=api_key,
+                    api_endpoint=api_endpoint,
+                    **kwargs
+                )
             elif backend == "openai":
                 completion = OpenaiAI.getChatCompletion(
                     messages_copy,
@@ -1051,7 +1063,7 @@ def agentmake(
 
         # update the message list
         if not agent_response:
-            messages_copy.append({"role": "assistant", "content": output if output else "Done!"})
+            messages_copy.append({"role": "assistant", "content": output if output else "[NO_CONTENT]"})
 
         # restore system message
         if original_system:
@@ -1444,6 +1456,21 @@ def getDictionaryOutput(
                 api_endpoint=api_endpoint,
                 **kwargs
             )
+        elif backend == "ollamacloud":
+            return OllamacloudAI.getDictionaryOutput(
+                messages,
+                schema,
+                model=model,
+                model_keep_alive=model_keep_alive,
+                temperature=temperature,
+                max_tokens=max_tokens,
+                context_window=context_window,
+                batch_size=batch_size,
+                prefill=prefill,
+                stop=stop,
+                api_endpoint=api_endpoint,
+                **kwargs
+            )
         elif backend == "openai":
             return OpenaiAI.getDictionaryOutput(
                 messages,
@@ -1542,6 +1569,11 @@ def extractText(item: Any, image_backend: str=DEFAULT_AI_BACKEND, llm_model: str
             if not llm_model:
                 llm_model = os.getenv("OLLAMA_VISUAL_MODEL") if os.getenv("OLLAMA_VISUAL_MODEL") else "granite3.2-vision"
             return OpenAI(base_url=f"{OllamaAI.DEFAULT_ENDPOINT}/v1")
+        elif image_backend == "ollamacloud":
+            from openai import OpenAI
+            if not llm_model:
+                llm_model = os.getenv("OLLAMACLOUD_VISUAL_MODEL") if os.getenv("OLLAMACLOUD_VISUAL_MODEL") else "qwen3-vl:235b"
+            return OpenAI(base_url=f"{OllamacloudAI.DEFAULT_ENDPOINT}/v1")
         elif image_backend == "googleai":
             if not llm_model:
                 llm_model = os.getenv("GOOGLEAI_VISUAL_MODEL") if os.getenv("GOOGLEAI_VISUAL_MODEL") else "gemini-2.5-pro"
