@@ -4,9 +4,17 @@ TOOL_DESCRIPTION = """Get bible verse smart indexes."""
 
 def index(messages, **kwargs):
     from agentmake.utils.online import get_local_ip
-    import requests, os
+    import requests, os, re
+    import urllib.parse
+    from agentmake.plugins.uba.lib.BibleParser import BibleVerseParser
 
-    command = "INDEX:::" + messages[-1].get("content", "")
+    command = messages[-1].get("content", "")
+    command = BibleVerseParser(False).extractAllReferencesReadable(command)
+    if not command:
+        print("Please provide a valid Bible reference to complete your request.")
+        return ""
+    command = urllib.parse.quote_plus(command)
+    command = f"INDEX:::{command}"
 
     UBA_API_LOCAL_PORT = int(os.getenv("UBA_API_LOCAL_PORT")) if os.getenv("UBA_API_LOCAL_PORT") else 8080
     UBA_API_ENDPOINT = os.getenv("UBA_API_ENDPOINT") if os.getenv("UBA_API_ENDPOINT") else f"http://{get_local_ip()}:{UBA_API_LOCAL_PORT}/plain" # use dynamic local ip if endpoint is not specified
@@ -19,7 +27,12 @@ def index(messages, **kwargs):
     try:
         response = requests.get(url, timeout=UBA_API_TIMEOUT)
         response.encoding = "utf-8"
-        print(response.text.strip())
+        content = response.text.strip()
+        content = content.replace("\nsearch for a location", "").replace("""\nBible Locations\n\n[not applicable]""", "")
+        content = content.replace("search for a character\nsearch for a name & its meaning", "")
+        content = re.sub(r"\[search a .*?\n", "", content)
+        content = re.sub(r"\[search an encyclope.*?$", "", content)
+        print("## "+content.replace("[", "- ["))
     except Exception as err:
         print(f"An error occurred: {err}")
     
